"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findRowBy = exports.getLocatorByIndex = void 0;
exports.buildData = buildData;
/**
 * clickRowByIndex will select the row of the table based on the index, where
 * the index will start at 0. If an index is greater than available rows an
 * exception will be thrown.
 */
const getLocatorByIndex = (dom, rowIndex) => __awaiter(void 0, void 0, void 0, function* () {
    const tbodyElements = dom.window.document.querySelectorAll('tbody');
    let rowCount = 0;
    tbodyElements.forEach((tbody) => {
        const rows = tbody.querySelectorAll('tr');
        rowCount += rows.length;
    });
    if (rowIndex + 1 > rowCount) {
        throw new Error(`Row Index is greater than table rows (${rowCount})`);
    }
    // return page.getByTestId(dataTestId).locator("tbody tr").nth(rowIndex).click();
    return 'TBA';
});
exports.getLocatorByIndex = getLocatorByIndex;
/**
 * findRowBy will return the index of the row in the DataTable if found.
 * Otherwise it will log out the attempted target and return -1.
 */
const findRowBy = (tableData, targetColumn, targetValue) => {
    if (!tableData) {
        throw new Error('DataTable cannot be undefined!');
    }
    if (!targetValue) {
        throw new Error('Target value cannot be undefined!');
    }
    const index = tableData.findIndex((item) => item[targetColumn] === targetValue);
    if (index === -1) {
        console.log(`Proceeding; Column header "${targetColumn}" with "${targetValue}" was not found! Returning '-1'"`);
        return -1;
    }
    return index;
};
exports.findRowBy = findRowBy;
// buildData returns a formatted data-structure for table cells
function buildData(rows, headers) {
    // Build the array of data
    const tableData = rows.map((row) => row.reduce((rowData, cell, index) => {
        rowData[headers[index]] = cell;
        return rowData;
    }, {}));
    return tableData;
}
